@@ -15,7 +15,7 @@ use Time::Piece ();
 has 'mysql';
 has 'no_txn' => sub { 0 };
 
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 # The dequeue system has a couple limitations:
 # 1. There is no way to directly notify a sleeping worker of an incoming
@@ -1157,6 +1157,23 @@ sub receive {
 #pod
 #pod =back
 #pod
+#pod =head1 ERRORS
+#pod
+#pod =head2 DBD::mysql::st execute failed: Table '*.minion_workers' doesn't exist
+#pod
+#pod This may happen when the SQL create/upgrade scripts fail to run
+#pod completely due to permission errors. Re-running with the environment
+#pod variable C<MOJO_MIGRATIONS_DEBUG=1> should produce the error message
+#pod returned by the database.
+#pod
+#pod A common reason for the database install to fail on MySQL >= 8 is that
+#pod the user installing the database does not have C<SUPER> privileges
+#pod needed to create functions when binlogs are enabled: (C<DBD::mysql::st
+#pod execute failed: You do not have the SUPER privilege and binary logging
+#pod is enabled>). See L<the MySQL documentation for Stored Program Binary
+#pod Logging|https://dev.mysql.com/doc/refman/8.0/en/stored-programs-logging.html>
+#pod for more information about this problem and how to correct it.
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod L<Minion>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
@@ -1173,7 +1190,7 @@ Minion::Backend::mysql
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -1586,6 +1603,23 @@ Time worker was started.
 
 =back
 
+=head1 ERRORS
+
+=head2 DBD::mysql::st execute failed: Table '*.minion_workers' doesn't exist
+
+This may happen when the SQL create/upgrade scripts fail to run
+completely due to permission errors. Re-running with the environment
+variable C<MOJO_MIGRATIONS_DEBUG=1> should produce the error message
+returned by the database.
+
+A common reason for the database install to fail on MySQL >= 8 is that
+the user installing the database does not have C<SUPER> privileges
+needed to create functions when binlogs are enabled: (C<DBD::mysql::st
+execute failed: You do not have the SUPER privilege and binary logging
+is enabled>). See L<the MySQL documentation for Stored Program Binary
+Logging|https://dev.mysql.com/doc/refman/8.0/en/stored-programs-logging.html>
+for more information about this problem and how to correct it.
+
 =head1 SEE ALSO
 
 L<Minion>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
